==> digikam-4.3.0.tar.bz2: digikam-4.3.0/extra/kipi-plugins/debianscreenshots/kipiplugin_debianscreenshots.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Debian Screenshots Export
Name=Debian Screenshots Export
Name[bg]=Изнасяне на снимки на екрана от Debian
Name[bs]=Izvoz Debian slika ekrana
Name[ca]=Exportador a Debian Screenshots
Name[ca@valencia]=Exportador a Debian Screenshots
Name[cs]=Export snímků obrazovky pro Debian
Name[da]=Eksport til Debian Screenshots
Name[de]=Export zu „Debian Screenshots“
Name[el]=Εξαγωγή στα Debian Screenshots
Name[en_GB]=Debian Screenshots Export
Name[es]=Exportación de pantallazos de Debian
Name[et]=Debiani ekraanipiltide eksport
Name[fr]=Exportation des captures d'écran Debian
Name[gl]=Exportación de pantallas para Debian
Name[hu]=Debian képernyőkép exportálás
Name[is]=Útflutningur í Debian skjámyndasafnið
Name[it]=Esportazione delle schermate di Debian
Name[km]=នាំចេញ​រូបថត​អេក្រង់​របស់​ដេបៀន
Name[nb]=Debian Screenshots-eksport
Name[nl]=Debian schermafdrukken exporteren
Name[pl]=Eksport do zrzutów ekranu Debiana
Name[pt]=Exportação para as Imagens da Debian
Name[pt_BR]=Exportar para o Debian Screenshots
Name[ro]=Export către capturile de ecran Debian
Name[ru]=Экспорт в снимки экрана Debian
Name[sk]=Export Debian Screenshots
Name[sl]=Izvoz v Debian Screenshots
Name[sv]=Exportera skärmbilder för Debian
Name[tr]=Debian Ekran Görüntüsü Aktarımı
Name[uk]=Експортування до знімків Debian
Name[x-test]=xxDebian Screenshots Exportxx
Name[zh_CN]=Debian 截图导出
Name[zh_TW]=Debian Screenshots 匯出
Comment=A tool to export images to the Debian Screenshots site
Comment[bg]=Инструмент за изнасяне на изображения към сайт със снимки на екрана от Debian
Comment[bs]=Alat za izvoz slika ekrana na Debian sajt s slikama
Comment[ca]=Una eina per exportar imatges al lloc web de Debian Screenshots
Comment[ca@valencia]=Una eina per exportar imatges al lloc web de Debian Screenshots
Comment[cs]=Nástroj pro export obrázků na stránky snímků obrazovky Debianu
Comment[da]=Et værktøj til at eksportere billeder til websiden Debian Screenshots
Comment[de]=Ein Werkzeug, um Bilder zu „Debian Screenshots“ zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων στον ιστοχώρο Debian Screenshots
Comment[en_GB]=A tool to export images to the Debian Screenshots site
Comment[es]=Una herramienta para exportar imágenes a la página de pantallazos de Debian
Comment[et]=Tööriist piltide eksportimiseks Debiani ekraanipiltide saidile
Comment[fr]=Outil pour l'exportation d'images vers le site de captures d'écran de Debian
Comment[ga]=Uirlis a easpórtálann íomhánna go dtí an suíomh Debian Screenshots
Comment[gl]=Unha ferramenta para exportar imaxes ao sitio de capturas de pantalla de Debian
Comment[hu]=Egy eszköz képek exportálásához a Debian képernyőképek oldalra
Comment[is]=Verkfæri til að flytja myndir út í Debian skjámyndasafnið
Comment[it]=Uno strumento per esportare immagini al sito delle schermate di Debian
Comment[km]=ឧបករណ៍​សម្រាប់​នាំ​ចេញ​រូបភាព​ទៅ​កាន់តំបន់​រូបថត​អេក្រង់​របស់​ដេបៀន​
Comment[nb]=Et verktøy for å eksportere bilder til nettstedet Debian Screenshots
Comment[nl]=Een hulpmiddel om afbeeldingen te exporteren naar de Debian site voor schermafdrukken
Comment[pl]=Narzędzie do eksportowania obrazów do strony zrzutów ekranów Debiana
Comment[pt]=Uma ferramenta para exportar imagens para a página de Imagens da Debian
Comment[pt_BR]=Uma ferramenta para exportar imagens para o site Debian Screenshots
Comment[ro]=O unealtă de exportat imagini pe situl de capturi de ecran Debian
Comment[ru]=Инструмент для экспорта изображений на сайт снимков экрана Debian
Comment[sk]=Nástroj na export obrázkov na sieť Debian Screenshots
Comment[sl]=Orodje za izvoz slik na spletno stran Debian Screenshots
Comment[sv]=Ett verktyg för att exportera bilder till Debian Skärmbilder
Comment[tr]=Resimleri Debian Ekran Görüntüleri sitesine aktarmak için bir araç
Comment[uk]=Інструмент для експортування зображень до сховища знімків вікон Debian
Comment[x-test]=xxA tool to export images to the Debian Screenshots sitexx
Comment[zh_TW]=匯出影像到 Debian Screenshots 網站的工具
Type=Service
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_debianscreenshots
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
Icon=kipi-debianscreenshots
author=Pau Garcia i Quiles, pgquiles at elpauer dot org

==> digikam-4.6.0.tar.bz2: digikam-4.6.0/extra/kipi-plugins/debianscreenshots/kipiplugin_debianscreenshots.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Debian Screenshots Export
Name=Debian Screenshots Export
Name[bg]=Изнасяне на снимки на екрана от Debian
Name[bs]=Izvoz Debian slika ekrana
Name[ca]=Exportador a Debian Screenshots
Name[ca@valencia]=Exportador a Debian Screenshots
Name[cs]=Export snímků obrazovky pro Debian
Name[da]=Eksport til Debian Screenshots
Name[de]=Export zu „Debian Screenshots“
Name[el]=Εξαγωγή στα Debian Screenshots
Name[en_GB]=Debian Screenshots Export
Name[es]=Exportación de pantallazos de Debian
Name[et]=Debiani ekraanipiltide eksport
Name[fi]=Debian Screenshots -vienti
Name[fr]=Exportation des captures d'écran Debian
Name[gl]=Exportación de pantallas para Debian
Name[hu]=Debian képernyőkép exportálás
Name[is]=Útflutningur í Debian skjámyndasafnið
Name[it]=Esportazione delle schermate di Debian
Name[km]=នាំចេញ​រូបថត​អេក្រង់​របស់​ដេបៀន
Name[nb]=Debian Screenshots-eksport
Name[nl]=Debian schermafdrukken exporteren
Name[pl]=Eksport do zrzutów ekranu Debiana
Name[pt]=Exportação para as Imagens da Debian
Name[pt_BR]=Exportar para o Debian Screenshots
Name[ro]=Export către capturile de ecran Debian
Name[ru]=Экспорт в снимки экрана Debian
Name[sk]=Export Debian Screenshots
Name[sl]=Izvoz v Debian Screenshots
Name[sv]=Exportera skärmbilder för Debian
Name[tr]=Debian Ekran Görüntüsü Aktarımı
Name[uk]=Експортування до знімків Debian
Name[x-test]=xxDebian Screenshots Exportxx
Name[zh_CN]=Debian 截图导出
Name[zh_TW]=Debian Screenshots 匯出
Comment=A tool to export images to the Debian Screenshots site
Comment[bg]=Инструмент за изнасяне на изображения към сайт със снимки на екрана от Debian
Comment[bs]=Alat za izvoz slika ekrana na Debian sajt s slikama
Comment[ca]=Una eina per exportar imatges al lloc web de Debian Screenshots
Comment[ca@valencia]=Una eina per exportar imatges al lloc web de Debian Screenshots
Comment[cs]=Nástroj pro export obrázků na stránky snímků obrazovky Debianu
Comment[da]=Et værktøj til at eksportere billeder til websiden Debian Screenshots
Comment[de]=Ein Werkzeug, um Bilder zu „Debian Screenshots“ zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων στον ιστοχώρο Debian Screenshots
Comment[en_GB]=A tool to export images to the Debian Screenshots site
Comment[es]=Una herramienta para exportar imágenes a la página de pantallazos de Debian
Comment[et]=Tööriist piltide eksportimiseks Debiani ekraanipiltide saidile
Comment[fi]=Kuvien vienti Debian Screenshots -sivustolle
Comment[fr]=Outil pour l'exportation d'images vers le site de captures d'écran de Debian
Comment[ga]=Uirlis a easpórtálann íomhánna go dtí an suíomh Debian Screenshots
Comment[gl]=Unha ferramenta para exportar imaxes ao sitio de capturas de pantalla de Debian
Comment[hu]=Egy eszköz képek exportálásához a Debian képernyőképek oldalra
Comment[is]=Verkfæri til að flytja myndir út í Debian skjámyndasafnið
Comment[it]=Uno strumento per esportare immagini al sito delle schermate di Debian
Comment[km]=ឧបករណ៍​សម្រាប់​នាំ​ចេញ​រូបភាព​ទៅ​កាន់តំបន់​រូបថត​អេក្រង់​របស់​ដេបៀន​
Comment[nb]=Et verktøy for å eksportere bilder til nettstedet Debian Screenshots
Comment[nl]=Een hulpmiddel om afbeeldingen te exporteren naar de Debian site voor schermafdrukken
Comment[pl]=Narzędzie do eksportowania obrazów do strony zrzutów ekranów Debiana
Comment[pt]=Uma ferramenta para exportar imagens para a página de Imagens da Debian
Comment[pt_BR]=Ferramenta para exportar imagens para o site Debian Screenshots
Comment[ro]=O unealtă de exportat imagini pe situl de capturi de ecran Debian
Comment[ru]=Инструмент для экспорта изображений на сайт снимков экрана Debian
Comment[sk]=Nástroj na export obrázkov na sieť Debian Screenshots
Comment[sl]=Orodje za izvoz slik na spletno stran Debian Screenshots
Comment[sv]=Ett verktyg för att exportera bilder till Debian Skärmbilder
Comment[tr]=Resimleri Debian Ekran Görüntüleri sitesine aktarmak için bir araç
Comment[uk]=Інструмент для експортування зображень до сховища знімків вікон Debian
Comment[x-test]=xxA tool to export images to the Debian Screenshots sitexx
Comment[zh_TW]=匯出影像到 Debian Screenshots 網站的工具
Type=Service
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_debianscreenshots
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
Icon=kipi-debianscreenshots
author=Pau Garcia i Quiles, pgquiles at elpauer dot org
